尊敬的Tushare社区用户，

感谢您长期以来对Tushare社区的信任与支持。自2014年底至今，Tushare已免费运行超过十年，期间我们投入了大量时间和精力，这远超常人的想象。然而，每年不断攀升的服务器和带宽成本已成为我们难以承受的压力。

特别是自Pro版上线以来，数据采集和处理的需求日益增加，用户请求也在持续增长，这些都给我们的服务器和带宽扩容带来了巨大挑战。为了确保社区能够持续健康发展，并不断提升数据服务的流畅性，我们恳请您理解并体谅我们在维护高质量数据过程中所付出的努力与决心。

您的关爱和支持是我们前进的动力源泉。我们将铭记这份信任，并将其转化为更加坚定的力量，继续秉持“数据信仰”，为用户提供更加优质、可靠的服务。

再次感谢您的支持与理解！

捐助方式一，扫码支付（支持微信、支付宝、云闪付等）, 请在支付时备注您的tushare账号（手机号或者数字ID），同时把支付截图发送给您对接的Tushare服务人员，如果还从未联系过，请加微信：waditu_a

所有捐助的用户，我们会将捐助金额转换成Tushare Pro积分，等同数据调取权限。除分钟数据和港美股外，目前捐助比例为1：10，即100元可以转换成1000积分（积分有效期一年）。

有任何问题，欢迎加微信好友:waditu_a，请根据需求考虑是否捐助获得权限或积分，一旦捐助后费用转入阿里云等云商充值，不支持退款，请谅解。